# Terms & Conditions

Last updated: Oct 29, 2020

Please read these terms and conditions carefully before using Our Service.

## Interpretation and Definitions

### Interpretation

The words of which the initial letter is capitalized have meanings defined under the
following conditions. The following definitions shall have the same meaning regardless of
whether they appear in singular or in plural.

### Definitions

For the purposes of these Terms and Conditions:

<ol type="a">

<li><b>Affiliate</b> means an entity that controls, is controlled by or is under common
   control with a party, where "control" means ownership of 50% or more of the
   shares, equity interest or other securities entitled to vote for election of directors
   or other managing authority.</li> 
<li><b>Account</b> means a unique account created for You to access our Service or parts
of our Service.</li>
<li><b>Country</b> refers to: Baden-Württemberg, Germany</li>   
<li><b>University</b> (referred to as either "the University", “Contact.engineering”, "We",
"Us" or "Our" in this Agreement) refers to Albert-Ludwigs-Universität Freiburg,
Georges-Köhler-Allee 103, 79110 Freiburg.</li>
<li><b>Content</b> refers to content such as text, images, or other information that can be
posted, uploaded, linked to or otherwise made available by You, regardless of
the form of that content.</li>
<li><b>Device</b> means any device that can access the Service such as a computer, a
cellphone or a digital tablet.</li>
<li><b>Feedback</b> means feedback, innovations or suggestions sent by You regarding
the attributes, performance or features of our Service.</li>
<li><b>Service</b> refers to the Website.</li>
<li><b>Terms and Conditions</b> (also referred as "Terms") mean these Terms and
Conditions that form the entire agreement between You and the University
regarding the use of the Service.</li>
<li><b>Third-party Social Media Service</b> means any services or content (including
data, information, products or services) provided by a third-party that may be
displayed, included or made available by the Service.
<li><b>Website</b> refers to contact.engineering, accessible 
from <a href="https://contact.engineering/">https://contact.engineering/</a></li>
<li><b>You</b> means the individual accessing or using the Service, or the University, or
other legal entity on behalf of which such individual is accessing or using the
Service, as applicable.</li>
</ol>

## Acknowledgment

These are the Terms and Conditions governing the use of this Service and the agreement
that operates between You and the University. These Terms and Conditions set out the
rights and obligations of all users regarding the use of the Service.

Your access to and use of the Service is conditioned on Your acceptance of and compliance
with these Terms and Conditions. These Terms and Conditions apply to all visitors, users
and others who access or use the Service.

By accessing or using the Service You agree to be bound by these Terms and Conditions. If
You disagree with any part of these Terms and Conditions then You may not access the
Service.

You represent that you are over the age of 18. The University does not permit those under
18 to use the Service.

Your access to and use of the Service is also conditioned on Your acceptance of and
compliance with the Privacy Policy of the University. Our Privacy Policy describes Our
policies and procedures on the collection, use and disclosure of Your personal information
when You use the Application or the Website and tells You about Your privacy rights and
how the law protects You. Please read Our Privacy Policy carefully before using Our Service.

## User Accounts

In order to user our Services, You need to have an ORCID iD. Your ORCID iD is a unique,
open digital identifier that distinguishes you from every other researcher with the same or
a similar name to you. To register and for more information, visit the 
<a href="https://orcid.org/register">ORCID website</a>.

When You create an account with Us, You must provide Us information that is accurate,
complete, and current at all times. Failure to do so constitutes a breach of the Terms, which
may result in immediate termination of Your account on Our Service.

You are responsible for safeguarding the password that You use to access the Service and
for any activities or actions under Your password, whether Your password is with Your
ORCID iD or a Third-Party Social Media Service.

You agree not to disclose Your password to any third party. You must notify Us immediately
upon becoming aware of any breach of security or unauthorized use of Your account.

You may not use as a user’s mail address or name or ORCID iD the mail address or name or
ORCID iD of another person or entity or that is not lawfully available for use, a name or
trademark that is subject to any rights of another person or entity other than You without
appropriate authorization, or a name or mail address that is otherwise offensive, vulgar or
obscene.

## Content

### Your Right to Post Content

Our Service allows You to post Content. You are responsible for the Content that You post to
the Service, including its legality, reliability, and appropriateness.

By posting Content to the Service, You grant Us the right and license to use, modify, publicly
perform, publicly display, reproduce, and distribute such Content on and through the
Service. You retain any and all of Your rights to any Content You submit, post or display on
or through the Service and You are responsible for protecting those rights. You agree that
this license includes the right for Us to make Your Content available to other users of the
Service, who may also use Your Content subject to these Terms.

You represent and warrant that: (i) the Content is Yours (You own it) or You have the right
to use it and grant Us the rights and license as provided in these Terms, and (ii) the posting
of Your Content on or through the Service does not violate the privacy rights, publicity
rights, copyrights, contract rights or any other rights of any person.

### Content Restrictions

The University is not responsible for the content of the Service's users. You expressly
understand and agree that You are solely responsible for the Content and for all activity that
occurs under your account, whether done so by You or any third person using Your account.

You may not transmit any Content that is unlawful, offensive, upsetting, intended to disgust,
threatening, libelous, defamatory, obscene or otherwise objectionable. Examples of such
objectionable Content include, but are not limited to, the following:

- Unlawful or promoting unlawful activity.
- Defamatory, discriminatory, or mean-spirited content, including references or
  commentary about religion, race, sexual orientation, gender, national/ethnic origin, or
  other targeted groups.
- Spam, machine – or randomly – generated, constituting unauthorized or unsolicited
  advertising, chain letters, any other form of unauthorized solicitation, or any form of
  lottery or gambling.
- Containing or installing any viruses, worms, malware, trojan horses, or other content
  that is designed or intended to disrupt, damage, or limit the functioning of any software,
  hardware or telecommunications equipment or to damage or obtain unauthorized
  access to any data or other information of a third person.
- Infringing on any proprietary rights of any party, including patent, trademark, trade
  secret, copyright, right of publicity or other rights.
- Impersonating any person or entity including the University and its employees or
  representatives.
- Violating the privacy of any third person.
- False information and features.

The University reserves the right, but not the obligation, to, in its sole discretion, determine
whether or not any Content is appropriate and complies with this Terms, refuse or remove
this Content. The University further reserves the right to make formatting and edits and
change the manner any Content. The University can also limit or revoke the use of the
Service if You post such objectionable Content. As the University cannot control all content
posted by users and/or third parties on the Service, you agree to use the Service at your
own risk. You understand that by using the Service You may be exposed to content that You
may find offensive, indecent, incorrect or objectionable, and You agree that under no
circumstances will the University be liable in any way for any content, including any errors
or omissions in any content, or any loss or damage of any kind incurred as a result of your
use of any content.  

### Content Backups

Although regular backups of Content are performed, the University does not guarantee
there will be no loss or corruption of data.

Corrupt or invalid backup points may be caused by, without limitation, Content that is
corrupted prior to being backed up or that changes during the time a backup is performed.

The University will provide support and attempt to troubleshoot any known or discovered
issues that may affect the backups of Content. But You acknowledge that the University has
no liability related to the integrity of Content or the failure to successfully restore Content to
a usable state.

You agree to maintain a complete and accurate copy of any Content in a location
independent of the Service.

## Your Feedback to Us

You assign all rights, title and interest in any Feedback You provide the University. If for any
reason such assignment is ineffective, You agree to grant the University a non-exclusive,perpetual, irrevocable, royalty free, worldwide right and license to use, reproduce, disclose,
sub-license, distribute, modify and exploit such Feedback without restriction.

## Links to Other Websites

Our Service may contain links to third-party web sites or services that are not owned or
controlled by the University.

The University has no control over, and assumes no responsibility for, the content, privacy
policies, or practices of any third party web sites or services. You further acknowledge and
agree that the University shall not be responsible or liable, directly or indirectly, for any
damage or loss caused or alleged to be caused by or in connection with the use of or reliance
on any such content, goods or services available on or through any such web sites or
services.

We strongly advise You to read the terms and conditions and privacy policies of any third-
party web sites or services that You visit.

## Termination

We may terminate or suspend Your Account immediately, without prior notice or liability,
for any reason whatsoever, including without limitation if You breach these Terms and
Conditions.
Upon termination, Your right to use the Service will cease immediately. If You wish to
terminate Your Account, You may simply discontinue using the Service.

## Disclaimers

1. Contact.engineering provides the Website and Service on an "as-is" and "as-
available" basis without any representations or warranties. It disclaims all
warranties, whether express or implied, including any warranties of fitness for a
particular purpose, security, quality, accuracy, completeness, truthfulness and
non-infringement.
2. Contact.engineering does not warrant that the Service will meet the requirements
of users, that the Service will be uninterrupted, punctual, secure or error-free, that
the information provided through the Service is accurate, reliable or correct, that
all defects or errors will be corrected, or that the Service is free of viruses or other
destructive features.
3. Contact.engineering does not promise that the Service will be available at a
certain time or place or that the Service or software will be available from the
server infrastructure without interruption.
4. Users assume total responsibility and the risk of loss resulting from the
downloading and/or use of files, information, Content or other materials made
available through Contact.engineering.

## Limitation of Liability

<ol>
<li>Contact.engineering will not be liable to You for lost profits, outages, financial
losses, loss of economic benefits or loss of data or damage caused by
    <ol type="a">
    <li>the use or disclosure of user-generated Content;</li>
    <li>the use, suspension of use or the termination of use of the Service;</li>
    <li>unauthorized access to the system or to the transmission of data;</li>
    <li>statements or conduct of third parties with respect to the Service; or</li>
    <li>any other user interactions that occur while using the Service.</li>
    </ol>
</li>
<li>Contact.engineering is not liable for outages or delays caused by matters that are
beyond the reasonable control of Contact.engineering.
The limitation of liability does not apply to any loss or damage caused by
intentional wrongdoing or gross negligence on the part of Contact.engineering.</li>
</ol>

## Indemnity

1. You agree to indemnify and hold Contact.engineering harmless from any claims
that third parties assert against it due to an infringement of their rights by Content
that You post to Contact.engineering or due to any other use by You of the
applications available via Contact.engineering. You agree to bear the costs of
any necessary defense to such claims by Contact.engineering, including any
court or attorney's fees in the statutory amount. This does not apply if the
infringement did not result from intentional misconduct or negligence on Your
part.
2. In the event that a third party brings a claim against Contact.engineering, You are
obliged to immediately provide it, truthfully and completely, with any information
that You have that is needed for an examination of the claim and for mounting a
defense. The aforegoing is without prejudice to any further damages claims that
Contact.engineering may have against You.
3. You bear sole responsibility for ensuring that the data and/or Devices that You
use in connection with the Website are adequately protected and backed-up. In
no event will You hold Contact.engineering liable for lost data, retransmission
times, inaccurate results, work delays or loss of profit due to the use of the
Content.

## Privacy Policy

Please find the information that is required for the contact.engineering Website pursuant
to Articles 13 and 14 of the General Data Protection Regulation (GDPR).

The protection of Your personal data is of utmost importance to the University of
Freiburg and We would like You to be as well informed as possible about how the data
are processed.

We process Your personal data (hereinafter referred to as "Data") in accordance with
the legal requirements and do so in a transparent manner. In this Privacy Policy, We
explain to You which data Contact.engineering processes in connection with the delivery
of its Service, the purpose of such processing and its legal basis. You will also receive
information about contact persons and Your rights.

### Controller for the Purposes of Data Protection Law

<p style="white-space: pre-wrap">
University of Freiburg
Friedrichstraße 39, 79098 Freiburg
+49 761/203-0
<a href="mailto:datenschutz@uni-freiburg.de">datenschutz@uni-freiburg.de</a>
<a href="https://www.uni-freiburg.de">https://www.uni-freiburg.de</a>
</p>

### Data Protection Officer

<p style="white-space: pre-wrap">
University of Freiburg
Data Protection Officer
Friedrichstraße 39, 79098 Freiburg
<a href="mailto:datenschutzbeauftragter@uni-freiburg.de">datenschutzbeauftragter@uni-freiburg.de</a>
</p>

### Responsible Internal Body

<p style="white-space: pre-wrap">
University of Freiburg
IMTEK - Institute for Microsystems Technology
Professor Lars Pastewka
Georges-Köhler-Allee 103
79110 Freiburg
<a href="mailto:simulation@imtek.uni-freiburg.de">simulation@imtek.uni-freiburg.de</a>
</p>

## Purpose of Data Processing

### Registration and Use

- Delivery of the Service, its Features and Content
- Delivery and acceptance of Content, communication with users·
- Security measures

### IP Address

In order to be able to deliver Our Website to a user’s computer, it is necessary for Our
system to temporarily store the user’s IP address. For this purpose, the user's IP
address must remain stored for the duration of a session.

### Log Files

Your data are stored in log files in order to ensure the functionality of the Website. In
addition, We use the data to optimize Our Website and to safeguard the security of Our
information technology systems. Such data are not combined with any of Your other
personal data.

### Cookies

We use cookies on Our Website. Cookies are small text files that are stored on Your
system in Your browser’s cache when You visit a website. They allow Our web server to
identify the browser that You are using and to recognize You when You return. In
particular, We use persistent cookies for analyzing Our Website. Persistent cookies are
automatically deleted after a predefined period of time, which can differ depending on
the cookie. This processing serves Our legitimate interest in making Our website more
user-friendly, more effective and more secure. You may, at any time, delete the cookies
in the security settings of Your browser. You may configure Your browser settings to
generally object to the use of cookies.

## Categories of Data

We collect the following categories of personal data directly from You when You register
and verify Your identity.

- Master data
  - Personal OpenResearcher and ContributorID (ORCID iD )
  - First and last name
- Contact details
  - E-mail address
- Content data
  - Research data, photos, video
- Usage data
  - Time and date of Your visit
  - Website used for access (Referrer URL)
- Metadata / Communication Data
  - IP address of Device
  - Name and URL of the accessed file
  - Browser used and, if applicable, the operating system 
    of Your computer and the name of Your access provider
  - Name of Your Internet service provider
  
## Legal Basis of Data Processing
- Art. 6(1)(b) and (e) and Art. 6(3) of the GDPR

  This data are collected and processed for the purpose of performing the license
  (master data, contact details).
- Art. 6(1)(a) and Art. 7 of the GDPR

  The data subject has given his/her consent to the processing of his/her personal
  data for one or more specific purposes (master data, contact details, Content
  information).
- Art 6(1)(f) of the GDPR

  Processing is necessary for the purposes of the legitimate interests pursued by the
  controller or by a third party (meta data, communication data, usage data).
  
## Data Security

We have adopted comprehensive technical and organizational measures to protect Your
personal data against unauthorized access, abuse, loss and other external interference.
To this end, We regularly review Our security measures and adapt them so that they are
state of the art.

All data processed in connection with the Service are stored on the servers of the
University of Freiburg’s data center.

## Storage Duration or Criteria for Determining the Duration of Storage

The above-mentioned data will be processed for as long as this is necessary to facilitate
the use of the Contact.engineering Service or to fulfill Our obligations or the statutory
obligations.

As a rule, account data are stored securely until the deletion of the user's Account and
then deleted within 3 months from the time that he/she closes his/her Account. 
After the deletion of a user’s Account, data that this user has published using 
Our application will be retained together with the ORCID iD for the purposes of dealing
with any legal issues or violations of good scientific practice.

Where data are recorded for the purpose of the delivery of the Website, this is the case
when the respective session is ended.

As a rule, the IP address and hardware information of a Device are usually stored in the
server’s access and error log for a period of seven days so that any errors may be
analyzed.

## Recipient Categories

Internal recipients are those employees who require the data so that they can perform
their tasks. Should We be required by law to disclose data, additional recipients will be
added.

## Your Rights as a Data Subject

1. You have the right to obtain information from the University of Freiburg at any
time about the personal data that We have stored about You and to request the
rectification of any inaccuracies.
2. You also have a right to erasure, a right to restriction of processing and a right to
object to processing.
3. Furthermore, if You have given us Your consent to processing, You have the
right to withdraw such consent at any time. The withdrawal of Your consent will
not affect the lawfulness of processing based on Your consent before its
withdrawal. You may, of course, also withdraw Your consent to the processing of
specific data. In the event that You do not give Your consent to processing or that
You withdraw it, You will not suffer any disadvantages.
4. You also have the right to lodge a complaint with a supervisory authority if You
are of the opinion that the processing of Your data infringes the law. One such
supervisory authority is, for example, the State Commissioner for Data Protection
and Freedom of Information in Baden-Württemberg, Königstraße 10a, 70173
Stuttgart, e-mail <a href="mailto:poststelle@lfdi.bwl.de">poststelle@lfdi.bwl.de</a>
(<a href="https://www.baden-wuerttemberg.datenschutz.de/">https://www.baden-wuerttemberg.datenschutz.de/</a>).
5. If You wish to exercise any legal rights against the University of Freiburg, please
contact <a href="mailto:datenschutz@uni-freiburg.de">datenschutz@uni-freiburg.de</a>.

## Information About the Right to Object Pursuant to Article 21(1) of the GDPR

Where processing is based on Art. 6(1)(e) of the GDPR (performance of data processing
carried out in the public interest), You are entitled to object, at any time, to the
processing of any personal data relating to Your particular situation.

## Governing Law

The laws of the Country, excluding its conflicts of law rules, shall govern this Terms and
Your use of the Service. Your use of the Application may also be subject to other local, state,
national, or international laws.

## Disputes Resolution

If You have any concern or dispute about the Service, You agree to first try to resolve the
dispute informally by contacting the University.

## For European Union (EU) Users

If You are a European Union consumer, you will benefit from any mandatory provisions of
the law of the country in which you are resident in.

## Severability and Waiver

### Severability

If any provision of these Terms is held to be unenforceable or invalid, such provision will be
changed and interpreted to accomplish the objectives of such provision to the greatest
extent possible under applicable law and the remaining provisions will continue in full force
and effect.

### Waiver

Except as provided herein, the failure to exercise a right or to require performance of an
obligation under this Terms shall not affect a party's ability to exercise such right or require
such performance at any time thereafter nor shall be the waiver of a breach constitute a
waiver of any subsequent breach.

## Translation Interpretation

These Terms and Conditions may have been translated if We have made them available to
You on Our Service. You agree that the original English text shall prevail in the case of a
dispute.

## Changes to These Terms and Conditions

We reserve the right, at Our sole discretion, to modify or replace these Terms at any time. If
a revision is material We will make reasonable efforts to provide at least 30 days' notice
prior to any new terms taking effect. What constitutes a material change will be determined
at Our sole discretion.

By continuing to access or use Our Service after those revisions become effective, You agree
to be bound by the revised terms. If You do not agree to the new terms, in whole or in part,
please stop using the website and the Service.

## Contact Us
If you have any questions about these Terms and Conditions, You can contact us:

By email: <a href="mailto:topobank@imtek.uni-freiburg.de">topobank@imtek.uni-freiburg.de</a>





















  
  
  


































